s3

package
v0.0.0-...-d8b7156 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 15, 2016 License: MIT Imports: 26 Imported by: 0

Documentation

Overview

Package s3 provides an interface to Amazon S3 oject storage

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewFs

func NewFs(name, root string) (fs.Fs, error)

NewFs constructs an Fs from the path, bucket:path

Types

type Fs

type Fs struct {
	// contains filtered or unexported fields
}

Fs represents a remote s3 server

func (*Fs) Copy

func (f *Fs) Copy(src fs.Object, remote string) (fs.Object, error)

Copy src to this remote using server side copy operations.

This is stored with the remote path given

It returns the destination Object and a possible error

Will only be called if src.Fs().Name() == f.Name()

If it isn't possible then return fs.ErrorCantCopy

func (*Fs) Hashes

func (f *Fs) Hashes() fs.HashSet

Hashes returns the supported hash sets.

func (*Fs) List

func (f *Fs) List(out fs.ListOpts, dir string)

List lists files and directories to out

func (*Fs) Mkdir

func (f *Fs) Mkdir() error

Mkdir creates the bucket if it doesn't exist

func (*Fs) Name

func (f *Fs) Name() string

Name of the remote (as passed into NewFs)

func (*Fs) NewObject

func (f *Fs) NewObject(remote string) (fs.Object, error)

NewObject finds the Object at remote. If it can't be found it returns the error fs.ErrorObjectNotFound.

func (*Fs) Precision

func (f *Fs) Precision() time.Duration

Precision of the remote

func (*Fs) Put

func (f *Fs) Put(in io.Reader, src fs.ObjectInfo) (fs.Object, error)

Put the Object into the bucket

func (*Fs) Rmdir

func (f *Fs) Rmdir() error

Rmdir deletes the bucket if the fs is at the root

Returns an error if it isn't empty

func (*Fs) Root

func (f *Fs) Root() string

Root of the remote (as passed into NewFs)

func (*Fs) String

func (f *Fs) String() string

String converts this Fs to a string

type Object

type Object struct {
	// contains filtered or unexported fields
}

Object describes a s3 object

func (*Object) Fs

func (o *Object) Fs() fs.Info

Fs returns the parent Fs

func (*Object) Hash

func (o *Object) Hash(t fs.HashType) (string, error)

Hash returns the Md5sum of an object returning a lowercase hex string

func (*Object) MimeType

func (o *Object) MimeType() string

MimeType of an Object if known, "" otherwise

func (*Object) ModTime

func (o *Object) ModTime() time.Time

ModTime returns the modification time of the object

It attempts to read the objects mtime and if that isn't present the LastModified returned in the http headers

func (*Object) Open

func (o *Object) Open(options ...fs.OpenOption) (in io.ReadCloser, err error)

Open an object for read

func (*Object) Remote

func (o *Object) Remote() string

Remote returns the remote path

func (*Object) Remove

func (o *Object) Remove() error

Remove an object

func (*Object) SetModTime

func (o *Object) SetModTime(modTime time.Time) error

SetModTime sets the modification time of the local fs object

func (*Object) Size

func (o *Object) Size() int64

Size returns the size of an object in bytes

func (*Object) Storable

func (o *Object) Storable() bool

Storable raturns a boolean indicating if this object is storable

func (*Object) String

func (o *Object) String() string

Return a string version

func (*Object) Update

func (o *Object) Update(in io.Reader, src fs.ObjectInfo) error

Update the Object from in with modTime and size

Jump to